/*****************************************************************
 * adc.c
 * Analog-to digital conversion of temperature
 * For Rancilio Silvia Espresso machine
 * Target: AVR 8-bit MCU
 * Author: Marcus Nilsson
 * Created: 2010-04-29
 *****************************************************************/

#include <avr/io.h>
#include <avr/interrupt.h>
#include "adc.h"
#include "mem.h"

#define ADC_CAL  2  // Calibrate (1 LSB = 0.25 degrees)

// Setup ADC on temp sensor pin
// The ADC clock is generated by system clock by dividing it to get smaller frequency.
// The ADC requires a frequency between 50KHz to 200KHz.
// At higher frequency the conversion is fast while a lower frequency the conversion is more accurate
void adcSetup(void)
{
	ADMUX  = 0xC0; // Use internal voltage REF and use single ended input on ADC0
	SFIOR  = 0x00; // Use free running mode
	ADCSRA = 0xEF; // Start ADC and set lowest frequency 62.5kHz, auto trigger and interrupt
	adcValue = 80; // Set some value
	adcCount = 1;
}

// Read 10-bit ADC value from interrupt routine
// Read ADCL first and then ADCH
// Only 2 LSB are used from ADCH
ISR(SIG_ADC)
{
	UINT16 value = ADCL;
	value |= (ADCH << 8);
	adcValue += (value + ADC_CAL);
	adcCount++;
}
