/*****************************************************************
 * adc.h
 * Analog-to digital conversion of temperature
 * For Rancilio Silvia Espresso machine
 * Target: AVR 8-bit MCU
 * Author: Marcus Nilsson
 * Created: 2010-04-29
 *
 * Device: National Semiconductor LM35AH (TO-46 metal package)
 * -55 - +150*C +/-0.2*C
 * 0*C = 0.00V
 * 1*C = 0.01V
 * 2*C = 0.02V
 * etc.
 *
 * AVR has a 10 Bit ADC with a range of 0-1023 
 *
 * Use internal 2.56 volt reference for ADC
 * Use cap between AREF pin and GND for better noise immunity
 *
 * 0 = 0.00V
 * n = n*2.56/1024V
 * n*256/1024 degrees = n/4 degrees
 * 1023 = 2.56V
 *
 * 1 LSB = 0.25 degrees celsius
 *
 * When internal refernce is used, AVCC can be left unconnected.
 *
 * ADC uses PORTA[0]
 *****************************************************************/

#ifndef _ADC_H_
#define _ADC_H_

#include "def.h"

// Functions
void adcSetup(void);

#endif // EOF
