/*****************************************************************
 * buttons.c
 * Handling of buttons
 * For Rancilio Silvia Espresso machine
 * Target: AVR 8-bit MCU
 * Author: Marcus Nilsson
 * Created: 2010-04-22
 *****************************************************************/

#include <avr/io.h>

#include "buttons.h"

// Software filtering to read the button signals
// Use some value to loop for 30ms (Need to check for more than 10ms)
// Make sure the time is long enough even if it is interrupted by timer irq (>20ms)
#define BUTTON_FILTER_TIME  24000
/*
// timeout loop is 9 instructions
in   1 cycle
com  1 cycle
or   1 cycle
subi 1 cycle
sbci 1 cycle
ldi  1 cycle
cpi  1 cycle
cpc  1 cycle
brne 2 cycles

Total: 10 cycles at 8MHz = 1.25 us
30ms = 24000 loops
*/
UINT8 getButtons(void)
{
	static UINT8 last;
	UINT8 buttons1 = 0, buttons2 = 0;
	UINT16 timeout = BUTTON_FILTER_TIME;
	// Make two readings to get a stable value
	// Return previous reading if it is unstable
	while(timeout--)
	{
		buttons1 |= ~PINA;
	}
	timeout = BUTTON_FILTER_TIME;
	while(timeout--)
	{
		buttons2 |= ~PINA;
	}
	// Mask away PORTA0
	buttons1 &= 0xFE;
	buttons2 &= 0xFE;
	if(buttons1 == buttons2)
	{
		last = buttons1;
	}
	return last;
}

// After a menu button is pressed, wait for its release
void waitForMenuButtonsRelease(void)
{
	while(getButtons() & BUTTON_MENU_BUTTONS);
}

