/*****************************************************************
 * buttons.h
 * Handling of buttons
 * For Rancilio Silvia Espresso machine
 * Target: AVR 8-bit MCU
 * Author: Marcus Nilsson
 * Created: 2010-04-22
 *
 * Uses PORTA:1-7
 *
 * High level means button is off
 * When menu buttons are pressed we will read low level on pin.
 * When 230V switches are on, we will see a 50Hz square wave on pin.
 *****************************************************************/

#ifndef _BUTTONS_H_
#define _BUTTONS_H_

#include "def.h"

// Buttons
#define BUTTON_ENTER          0x02 //PORTA1
#define BUTTON_DOWN           0x04 //PORTA2
#define BUTTON_UP             0x08 //PORTA3
#define BUTTON_STEAM          0x10 //PORTA4
#define BUTTON_POWER          0x20 //PORTA5
#define BUTTON_BREW           0x40 //PORTA6
#define BUTTON_WATER          0x80 //PORTA7

// Bit masks
#define BUTTON_ANY_BUT_POWER  0xDE
#define BUTTON_MENU_BUTTONS   0x0E

// Functions
UINT8 getButtons(void);
void waitForMenuButtonsRelease(void);

#endif // EOF
