/*****************************************************************
 * display.h
 * Handling of LCD display
 * For Rancilio Silvia Espresso machine
 * Target: AVR 8-bit MCU
 * Author: Marcus Nilsson
 * Created: 2010-04-22
 *
 * The display is a 16x2 character red on black LCD
 * (GDM1602K) with backlight from Xiamen Ocular
 * It uses the HD44780 parallel interface
 *
 * Use a variable rsistor 10-20k to adjust contrast.
 * Use one pin for backligt 4.2V
 *****************************************************************/

/*
User menu
- Default display: Temp value+setpoint. Change brew mode: AUTO or MANUAL
- Enter standby
- Time since start (hours:minutes) updated continous
- Settings

Settings menu
- Brew temp setpoint (1C steps)
- Shot time (1s steps)
- Start time Mon-Fri (30min steps + enable/disable)
- Start time Sat-Sun (30min steps + enable/disable)
- Shot count
- Advanced settings
- Back

Advanced settings menu
- Time and weekday (Hour-Minute-Weekday)
- Steam temp setpoint (1C steps)
- Standby timeout. (1h steps)
- P-value
- I-value
- D-value
- Max steam time (1min steps)
- Cleaning threshold
- RS232 log on/off
- Debug info
- Back
*/

#ifndef _DISPLAY_H_
#define _DISLPAY_H_

#include "def.h"

// Special characters for LCD
#define CHAR_DEG             223 // Degrees
#define CHAR_ARROW_L         126 // Left arrow
#define CHAR_ARROW_R         127 // Right arrow

// Menus
#define MENU_USER            0
#define MENU_SETTINGS        1
#define MENU_ADVANCED        2

// Number of menu pages
#define MENU_USER_PAGES      4
#define MENU_SETTINGS_PAGES  7
#define MENU_ADVANCED_PAGES  13

// Min/max values
#define MIN_BREW_TEMP        50    // Degrees
#define MAX_BREW_TEMP        99    // Degrees
#define MIN_SHOT_TIME        1     // Seconds
#define MAX_SHOT_TIME        99    // Seconds
#define MIN_STEAM_TEMP       50    // Degrees
#define MAX_STEAM_TEMP       200   // Degrees
#define MIN_STANDBY_TIMEOUT  1     // Hours
#define MAX_STANDBY_TIMEOUT  20    // Hours
#define MIN_P                0
#define MAX_P                100
#define MIN_I                0
#define MAX_I                100
#define MIN_D                0
#define MAX_D                1000
#define MIN_STEAM_TIME       1     // Minutes
#define MAX_STEAM_TIME       30    // Minutes
#define MIN_CLEAN_LIMIT      1     // Shots
#define MAX_CLEAN_LIMIT      1000  // Shots

// Functions
void displayInit(void);
void displayOn(void);
void displayOff(void);
void displaySet(char *line1, char *line2);
void displayUpdateStandby(Time *time, StartTime *startTime);
void displayUpdateBrew(UINT8 elapsedTime, UINT8 autoBrewTime);
void displayUpdateSteam(void);
void displayUpdateWater(void);
BOOL displayUpdateMenu(UINT8 *page, UINT8 *menu, UINT8 button);
void menuNextPage(UINT8 *menuPage, UINT8 menu);

#endif // EOF

