/*****************************************************************
 * mem.h
 * Memory handling
 * For Rancilio Silvia Espresso machine
 * Target: AVR 8-bit MCU
 * Author: Marcus Nilsson
 * Created: 2011-01-25
 *
 * EEPROM 512b
 * SRAM   1kb
 * Flash  16kb
 *****************************************************************/

#ifndef _MEM_H_
#define _MEM_H_

#include "def.h"

extern UINT16 debugOutput;

// EEPROM addresses
// Counters
#define EE_COUNT_TOTAL        (UINT8*)0x000  // 4 bytes
#define EE_COUNT_CLEAN        (UINT8*)0x004  // 2 bytes
// Settings
#define EE_BREW_TEMP          (UINT8*)0x006  // 1 byte
#define EE_SHOT_TIME          (UINT8*)0x007  // 1 byte
#define EE_START_MONFRI       (UINT8*)0x008  // 2 bytes
#define EE_START_SATSUN       (UINT8*)0x00A  // 2 bytes
// Advanced settings
#define EE_STEAM_TEMP         (UINT8*)0x00C  // 1 byte
#define EE_STANDBY_TIMEOUT    (UINT8*)0x00D  // 1 byte
#define EE_P                  (UINT8*)0x00E  // 1 bytes
#define EE_I                  (UINT8*)0x00F  // 4 bytes
#define EE_D                  (UINT8*)0x013  // 4 bytes
#define EE_STEAM_TIME         (UINT8*)0x017  // 1 byte
#define EE_CLEAN_LIMIT        (UINT8*)0x018  // 2 bytes

// Globals
extern UINT8 heatMode;
extern UINT8 brewMode;
extern Time sysStartTime;
extern FLOAT32 currTemp;
extern BOOL logEnabled;
extern UINT8 brewTempSP;
extern UINT8 shotTime;
extern StartTime startMonFri;
extern StartTime startSatSun;
extern UINT8 steamTempSP;
extern UINT8 standbyTimeout;
extern UINT8 regP;
extern FLOAT32 regI;
extern FLOAT32 regD;
extern UINT8 maxSteamTime;
extern UINT16 cleanLimit;
extern UINT32 countTotal;
extern UINT16 countClean;
extern UINT32 adcValue;
extern UINT16 adcCount;

// Functions
void initRam(void);
void saveSettings(void);
void saveAdvancedSettings(void);
void saveCounters(void);
void incCounters(void);
void factoryReset(void);

#endif // EOF
